---
title: Kernel Services
author:
date: 2024-12-05
...

# Kernel Services

This section deals with requests related to the management
of the Frama-C platform and services offered by the kernel.
This covers several topics: configuration, logs.

Configuration deals with versioning and resource directories.
Project services allow to work with several Frama-C projects.

Logs are automatically tracked by the server plug-in and queued.
This monitoring can be controlled by `Kernel.SetLogs` command, but by
default, monitoring is turned on as soon as some server is started
(except for the batch server). The `Kernel.GetLogs` allow to flush this queue,
with a maximum number of messages. Non-flushed messages
can be recovered by subsequent calls, until the requests replies with an empty
message set.

However, logs emitted prior to the execution of a server, or after its shutdown,
are _not_ collected by default. To enable this monitoring, for instance to collect
messages before the server is started, you shall set the `-server-logs` option, which
takes effect at configuration time (you can also use `... -then -server-logs ...`).

## kernel.services.getConfig (`GET`) {#getconfig}

Frama-C Kernel configuration


> _input_ `::=` _null_
  

> _output_ `::=` `{` _output…_ `}`
  

| Output | Format | Description |
|:-------|:------:|:------------|
| `"version"` | _string_ | Frama-C version |
| `"datadir"` | _string_ `[]` | Shared directory (FRAMAC_SHARE) |
| `"pluginpath"` | _string_ `[]` | Plugin directories (FRAMAC_PLUGIN) |


## kernel.services.load (`SET`) {#load}

Load a save file. Returns an error, if not successfull.


> _input_ `::=` _string_
  

> _output_ `::=` _string_ `?`
  

## kernel.services.save (`SET`) {#save}

Save the current session. Returns an error, if not successfull.


> _input_ `::=` _string_
  

> _output_ `::=` _string_ `?`
  

## kernel.services.logkind (`DATA`) {#logkind}

Log messages categories.


> [`logkind`](#logkind)  `::=` _tags…_
  

| Tags | Value | Description |
|:-----|:------|:------------|
| Error | `"ERROR"` | User Error |
| Warning | `"WARNING"` | User Warning |
| Feedback | `"FEEDBACK"` | Plugin Feedback |
| Result | `"RESULT"` | Plugin Result |
| Failure | `"FAILURE"` | Plugin Failure |
| Debug | `"DEBUG"` | Analyser Debug |


## kernel.services.logkindTags (`GET`) {#logkindtags}

Registered tags for the above type.


> _input_ `::=` _null_
  

> _output_ `::=` [`tag`](data.md#tag)  `[]`
  

## kernel.services.message (`ARRAY`) {#message}

Log messages


## kernel.services.signalMessage (`SIGNAL`) {#signalmessage}

Signal for array [`message`](#message) 


## kernel.services.messageData (`DATA`) {#messagedata}

Data for array rows [`message`](#message) 


> [`messageData`](#messagedata)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"key"` | `$message` | Entry identifier. |
| `"kind"` | [`logkind`](services.md#logkind)  | Message kind |
| `"plugin"` | _string_ | Emitter plugin |
| `"message"` | _string_ | Message text |
| `"category"` (opt.) | _string_ | Message category (only for debug or warning messages) |
| `"source"` (opt.) | [`source`](ast.md#source)  | Source file position |
| `"marker"` (opt.) | [`marker`](ast.md#marker)  | Marker at the message position (if any) |
| `"decl"` (opt.) | [`decl`](ast.md#decl)  | Declaration containing the message position (if any) |


## kernel.services.fetchMessage (`GET`) {#fetchmessage}

Data fetcher for array [`message`](#message) 


> _input_ `::=` _number_
  

> _output_ `::=` `{` _output…_ `}`
  

| Output | Format | Description |
|:-------|:------:|:------------|
| `"reload"` | _boolean_ | array fully reloaded |
| `"removed"` | `$message` `[]` | removed entries |
| `"updated"` | [`messageData`](services.md#messagedata)  `[]` | updated entries |
| `"pending"` | _number_ | remaining entries to be fetched |


## kernel.services.reloadMessage (`GET`) {#reloadmessage}

Force full reload for array [`message`](#message) 


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## kernel.services.log (`DATA`) {#log}

Message event record.


> [`log`](#log)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"kind"` | [`logkind`](services.md#logkind)  | Message kind |
| `"plugin"` | _string_ | Emitter plugin |
| `"message"` | _string_ | Message text |
| `"category"` (opt.) | _string_ | Message category (DEBUG or WARNING) |
| `"source"` (opt.) | [`source`](ast.md#source)  | Source file position |


## kernel.services.setLogs (`SET`) {#setlogs}

Turn logs monitoring on/off


> _input_ `::=` _boolean_
  

> _output_ `::=` _null_
  

## kernel.services.getLogs (`GET`) {#getlogs}

Flush the last emitted logs since last call (max 100)


> _input_ `::=` _null_
  

> _output_ `::=` [`log`](services.md#log)  `[]`
  